==> python_bitpin-0.0.4.tar.gz: python_bitpin-0.0.4/README.md <==
# Python-Bitpin SDK

[![Poetry](https://img.shields.io/endpoint?url=https://python-poetry.org/badge/v0.json)](https://python-poetry.org/)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/python-bitpin)
![PyPI - Version](https://img.shields.io/pypi/v/python-bitpin)
[![Codacy Badge](https://app.codacy.com/project/badge/Grade/152926ced23a45c6abb55af6884f890f)](https://app.codacy.com/gh/amiwrpremium/python-bitpin/dashboard?utm_source=gh&utm_medium=referral&utm_content=&utm_campaign=Badge_grade)
![PyPI - License](https://img.shields.io/pypi/l/python-bitpin)
[![Documentation Status](https://readthedocs.org/projects/python-bitpin/badge/?version=latest)](https://python-bitpin.readthedocs.io/en/latest/?badge=latest)
[![Documentation Status](https://img.shields.io/badge/docs-mkdocs%20material-blue.svg?style=flat)](https://squidfunk.github.io/mkdocs-material/)
[![pydocstyle](https://img.shields.io/badge/pydocstyle-enabled-AD4CD3)](http://www.pydocstyle.org/en/stable/)
[![Checked with mypy](http://www.mypy-lang.org/static/mypy_badge.svg)](http://mypy-lang.org/)
[![linting: pylint](https://img.shields.io/badge/linting-pylint-yellowgreen)](https://github.com/pylint-dev/pylint)
[![Flake8 Status](./reports/flake8/flake8-badge.svg?dummy=8484744)](./reports/flake8/index.html)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)](https://github.com/pre-commit/pre-commit)
[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/amiwrpremium/python-bitpin/master.svg)](https://results.pre-commit.ci/latest/github/amiwrpremium/python-bitpin/master)
![GitHub Workflow Status](https://img.shields.io/github/actions/workflow/status/amiwrpremium/python-bitpin/publish.yml?label=publish)

## About

[Bitpin](https://bitpin.ir/) is an Iranian cryptocurrency exchange that allows
users to buy and sell cryptocurrencies using Iranian Rial (IRR).

**I'm in no way affiliated with Bitpin and this is not an official SDK.**

## Installation

Install using `pip` from [PyPI](https://pypi.org/project/python-bitpin/):
> pip install python-bitpin

Install from `git`
> pip install git+https://github.com/amiwrpremium/python-bitpin.git

## Usage

See [examples](https://python-bitpin.readthedocs.io/en/latest/examples/) for more usage examples.

## Documentation

See [documentation](https://python-bitpin.readthedocs.io/en/latest/).

## License

See [LICENSE](LICENSE).

## Disclaimer

This is not an official SDK, and I am in no way affiliated with Bitpin.

==> python_bitpin-0.0.5.tar.gz: python_bitpin-0.0.5/README.md <==
# Python-Bitpin SDK

[![Poetry](https://img.shields.io/endpoint?url=https://python-poetry.org/badge/v0.json)](https://python-poetry.org/)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/python-bitpin)
![PyPI - Version](https://img.shields.io/pypi/v/python-bitpin)
[![Codacy Badge](https://app.codacy.com/project/badge/Grade/152926ced23a45c6abb55af6884f890f)](https://app.codacy.com/gh/amiwrpremium/python-bitpin/dashboard?utm_source=gh&utm_medium=referral&utm_content=&utm_campaign=Badge_grade)
![PyPI - License](https://img.shields.io/pypi/l/python-bitpin)
[![Documentation Status](https://readthedocs.org/projects/python-bitpin/badge/?version=latest)](https://python-bitpin.readthedocs.io/en/latest/?badge=latest)
[![Documentation Status](https://img.shields.io/badge/docs-mkdocs%20material-blue.svg?style=flat)](https://squidfunk.github.io/mkdocs-material/)
[![pydocstyle](https://img.shields.io/badge/pydocstyle-enabled-AD4CD3)](http://www.pydocstyle.org/en/stable/)
[![Checked with mypy](http://www.mypy-lang.org/static/mypy_badge.svg)](http://mypy-lang.org/)
[![linting: pylint](https://img.shields.io/badge/linting-pylint-yellowgreen)](https://github.com/pylint-dev/pylint)
[![Flake8 Status](./reports/flake8/flake8-badge.svg?dummy=8484744)](./reports/flake8/index.html)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)](https://github.com/pre-commit/pre-commit)
[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/amiwrpremium/python-bitpin/master.svg)](https://results.pre-commit.ci/latest/github/amiwrpremium/python-bitpin/master)
![GitHub Workflow Status](https://img.shields.io/github/actions/workflow/status/amiwrpremium/python-bitpin/publish.yml?label=publish)

## About

[Bitpin](https://bitpin.ir/) is an Iranian cryptocurrency exchange that allows
users to buy and sell cryptocurrencies using Iranian Rial (IRR).

**I'm in no way affiliated with Bitpin and this is not an official SDK.**

## Installation

Install using `pip` from [PyPI](https://pypi.org/project/python-bitpin/):
> pip install python-bitpin

Install from `git`
> pip install git+https://github.com/amiwrpremium/python-bitpin.git

## Usage

See [usage](https://python-bitpin.readthedocs.io/en/latest/usage/) for usage guide.

## Documentation

See [documentation](https://python-bitpin.readthedocs.io/en/latest/).

## License

See [LICENSE](LICENSE).

## Disclaimer

This is not an official SDK, and I am in no way affiliated with Bitpin.
